@@ -867,6 +867,11 @@ def main():
 
     elif arguments["release"]:
 
+        testing = "TESTING" in os.environ
+
+        if testing:
+            del os.environ["TESTING"]
+
         os.system("pip install twine")
 
         repos = arguments["REPOS"]
@@ -884,6 +889,9 @@ def main():
 
         StopWatch.benchmark(sysinfo=True)
 
+        if testing:
+            os.environ["TESTING"] = 1
+
     elif arguments["--venv"] and arguments["clean"]:
         environment = arguments["--venv"]
 
